AdobeRgb

Type Alias AdobeRgb 

pub type AdobeRgb<T = f32> = Rgb<AdobeRgb, T>;
Non-linear Adobe RGB.

This is a gamma 2.2 encoded RGB color space designed to include most colors producable by CMYK printers.

See Rgb for more details on how to create a value and use it.

Aliased Type

#[repr(C)]
pub struct AdobeRgb<T = f32> { pub red: T, pub green: T, pub blue: T, pub standard: PhantomData<AdobeRgb>, }

Fields

red: T

The amount of red light, where 0.0 is no red light and 1.0 (or 255u8) is the highest displayable amount.

green: T

The amount of green light, where 0.0 is no green light and 1.0 (or 255u8) is the highest displayable amount.

blue: T

The amount of blue light, where 0.0 is no blue light and 1.0 (or 255u8) is the highest displayable amount.

standard: PhantomData<AdobeRgb>

The kind of RGB standard. sRGB is the default.