AdobeRgba

Type Alias AdobeRgba 

pub type AdobeRgba<T = f32> = Alpha<Rgb<AdobeRgb, T>, T>;
Non-linear Adobe RGB with an alpha component.

This is a transparent version of AdobeRgb, which is commonly used as the input or output format.

See Rgb, Rgba and Alpha for more details on how to create a value and use it.

Aliased Type

#[repr(C)]
pub struct AdobeRgba<T = f32> { pub color: Rgb<AdobeRgb, T>, pub alpha: T, }

Fields

color: Rgb<AdobeRgb, T>

The color.

alpha: T

The transparency component. 0.0 (or 0u8) is fully transparent and 1.0 (or 255u8) is fully opaque.