DciP3

Type Alias DciP3 

pub type DciP3<T = f32> = Rgb<DciP3, T>;
Non-linear DCI-P3, an RGB format used for digital movie distribution.

This is an RGB standard with a color gamut wider than that of Srgb and a white point similar to that of a film projector’s xenon bulb.

See Rgb for more details on how to create a value and use it.

Aliased Type

#[repr(C)]
pub struct DciP3<T = f32> { pub red: T, pub green: T, pub blue: T, pub standard: PhantomData<DciP3>, }

Fields

red: T

The amount of red light, where 0.0 is no red light and 1.0 (or 255u8) is the highest displayable amount.

green: T

The amount of green light, where 0.0 is no green light and 1.0 (or 255u8) is the highest displayable amount.

blue: T

The amount of blue light, where 0.0 is no blue light and 1.0 (or 255u8) is the highest displayable amount.

standard: PhantomData<DciP3>

The kind of RGB standard. sRGB is the default.