LinAdobeRgb

Type Alias LinAdobeRgb 

pub type LinAdobeRgb<T = f32> = Rgb<Linear<AdobeRgb>, T>;
Linear Adobe RGB.

You probably want AdobeRgb if you are looking for an input or output format. This is the linear version of Adobe RGB, which is what you would usually convert to before working with the color.

See Rgb for more details on how to create a value and use it.

Aliased Type

#[repr(C)]
pub struct LinAdobeRgb<T = f32> { pub red: T, pub green: T, pub blue: T, pub standard: PhantomData<Linear<AdobeRgb>>, }

Fields

red: T

The amount of red light, where 0.0 is no red light and 1.0 (or 255u8) is the highest displayable amount.

green: T

The amount of green light, where 0.0 is no green light and 1.0 (or 255u8) is the highest displayable amount.

blue: T

The amount of blue light, where 0.0 is no blue light and 1.0 (or 255u8) is the highest displayable amount.

standard: PhantomData<Linear<AdobeRgb>>

The kind of RGB standard. sRGB is the default.