LinAdobeRgba

Type Alias LinAdobeRgba 

pub type LinAdobeRgba<T = f32> = Alpha<Rgb<Linear<AdobeRgb>, T>, T>;
Linear Adobe RGB with an alpha component.

You probably want AdobeRgba if you are looking for an input or output format. This is the linear version of Adobe RGBA, which is what you would usually convert to before working with the color.

See Rgb, Rgba and Alpha for more details on how to create a value and use it.

Aliased Type

#[repr(C)]
pub struct LinAdobeRgba<T = f32> { pub color: Rgb<Linear<AdobeRgb>, T>, pub alpha: T, }

Fields

color: Rgb<Linear<AdobeRgb>, T>

The color.

alpha: T

The transparency component. 0.0 (or 0u8) is fully transparent and 1.0 (or 255u8) is fully opaque.