LinDciP3Plus

Type Alias LinDciP3Plus 

pub type LinDciP3Plus<F, T = f32> = Rgb<Linear<DciP3Plus<F>>, T>;
Linear DCI-P3+.

You probably want DciP3Plus if you are looking for an input or output format. This is the linear version of DCI-P3+, which is what you would usually convert to before working with the color.

See Rgb for more details on how to create a value and use it.

Aliased Type

#[repr(C)]
pub struct LinDciP3Plus<F, T = f32> { pub red: T, pub green: T, pub blue: T, pub standard: PhantomData<Linear<DciP3Plus<F>>>, }

Fields

red: T

The amount of red light, where 0.0 is no red light and 1.0 (or 255u8) is the highest displayable amount.

green: T

The amount of green light, where 0.0 is no green light and 1.0 (or 255u8) is the highest displayable amount.

blue: T

The amount of blue light, where 0.0 is no blue light and 1.0 (or 255u8) is the highest displayable amount.

standard: PhantomData<Linear<DciP3Plus<F>>>

The kind of RGB standard. sRGB is the default.