LinProPhotoRgba

Type Alias LinProPhotoRgba 

pub type LinProPhotoRgba<T = f32> = Alpha<Rgb<Linear<ProPhotoRgb>, T>, T>;
Linear ProPhoto RGB with an alpha component.

You probably want ProPhotoRgba if you are looking for an input or output format. This is the linear version of ProPhoto RGBA, which is what you would usually convert to before working with the color.

See Rgb, Rgba and Alpha for more details on how to create a value and use it.

Aliased Type

#[repr(C)]
pub struct LinProPhotoRgba<T = f32> { pub color: Rgb<Linear<ProPhotoRgb>, T>, pub alpha: T, }

Fields

color: Rgb<Linear<ProPhotoRgb>, T>

The color.

alpha: T

The transparency component. 0.0 (or 0u8) is fully transparent and 1.0 (or 255u8) is fully opaque.