ProPhotoRgba

Type Alias ProPhotoRgba 

pub type ProPhotoRgba<T = f32> = Alpha<Rgb<ProPhotoRgb, T>, T>;
Non-linear ProPhoto RGB with an alpha component.

This is a transparent version of ProPhotoRgb, which is commonly used as the input or output format.

See Rgb, Rgba and Alpha for more details on how to create a value and use it.

Aliased Type

#[repr(C)]
pub struct ProPhotoRgba<T = f32> { pub color: Rgb<ProPhotoRgb, T>, pub alpha: T, }

Fields

color: Rgb<ProPhotoRgb, T>

The color.

alpha: T

The transparency component. 0.0 (or 0u8) is fully transparent and 1.0 (or 255u8) is fully opaque.