Rec2020

Type Alias Rec2020 

pub type Rec2020<T = f32> = Rgb<Rec2020, T>;
Non-linear Rec. 2020, a wide color gamut RGB format.

This is an RGB standard with a color gamut much wider than that of Srgb.

See Rgb for more details on how to create a value and use it.

Aliased Type

#[repr(C)]
pub struct Rec2020<T = f32> { pub red: T, pub green: T, pub blue: T, pub standard: PhantomData<Rec2020>, }

Fields

red: T

The amount of red light, where 0.0 is no red light and 1.0 (or 255u8) is the highest displayable amount.

green: T

The amount of green light, where 0.0 is no green light and 1.0 (or 255u8) is the highest displayable amount.

blue: T

The amount of blue light, where 0.0 is no blue light and 1.0 (or 255u8) is the highest displayable amount.

standard: PhantomData<Rec2020>

The kind of RGB standard. sRGB is the default.