Rec709

Type Alias Rec709 

pub type Rec709<T = f32> = Rgb<Rec709, T>;
Non-linear Rec. 709.

This standard has the same primaries as Srgb, but uses the transfer function detailed in ITU-R Recommendation BT.709.

See Rgb for more details on how to create a value and use it.

Aliased Type

#[repr(C)]
pub struct Rec709<T = f32> { pub red: T, pub green: T, pub blue: T, pub standard: PhantomData<Rec709>, }

Fields

red: T

The amount of red light, where 0.0 is no red light and 1.0 (or 255u8) is the highest displayable amount.

green: T

The amount of green light, where 0.0 is no green light and 1.0 (or 255u8) is the highest displayable amount.

blue: T

The amount of blue light, where 0.0 is no blue light and 1.0 (or 255u8) is the highest displayable amount.

standard: PhantomData<Rec709>

The kind of RGB standard. sRGB is the default.