pub type DciP3Plus<F, T = f32> = Rgb<DciP3Plus<F>, T>;Expand description
Non-linear Canon DCI-P3+, an RGB format with a very wide gamut.
This is an RGB standard with a color gamut much wider than that of Srgb.
It uses the same white point as DciP3, but uses a user-defined transfer
function, represented here by the generic F.
See Rgb for more details on how to create a value and use it.
Aliased Type
#[repr(C)]pub struct DciP3Plus<F, T = f32> {
pub red: T,
pub green: T,
pub blue: T,
pub standard: PhantomData<DciP3Plus<F>>,
}Fields
red: TThe amount of red light, where 0.0 is no red light and 1.0 (or 255u8) is the highest displayable amount.
green: TThe amount of green light, where 0.0 is no green light and 1.0 (or 255u8) is the highest displayable amount.
blue: TThe amount of blue light, where 0.0 is no blue light and 1.0 (or 255u8) is the highest displayable amount.
standard: PhantomData<DciP3Plus<F>>The kind of RGB standard. sRGB is the default.