pub type ProPhotoRgb<T = f32> = Rgb<ProPhotoRgb, T>;Expand description
Non-linear ProPhoto RGB, a wide color gamut RGB format.
This is an RGB standard with a color gamut designed to include 100% of likely occurring real-world colors.
See Rgb for more details on how to create a value and use it.
Aliased Type
#[repr(C)]pub struct ProPhotoRgb<T = f32> {
pub red: T,
pub green: T,
pub blue: T,
pub standard: PhantomData<ProPhotoRgb>,
}Fields
red: TThe amount of red light, where 0.0 is no red light and 1.0 (or 255u8) is the highest displayable amount.
green: TThe amount of green light, where 0.0 is no green light and 1.0 (or 255u8) is the highest displayable amount.
blue: TThe amount of blue light, where 0.0 is no blue light and 1.0 (or 255u8) is the highest displayable amount.
standard: PhantomData<ProPhotoRgb>The kind of RGB standard. sRGB is the default.